<?php
/**
 * Contains methods for customizing the theme customization screen.
 *
 * @link http://codex.wordpress.org/Theme_Customization_API
 *
 */

if ( ! class_exists( 'Lesse_Customizer' ) ) {

	class Lesse_Customizer {

		public $custom_css = '';

		public function __construct() {
			add_action( 'customize_register', array( $this, 'register' ) );
			add_action( 'customize_preview_init', array( $this, 'live_preview' ) );
			add_action( 'wp_head', array( $this, 'generate_custom_css' ) );
			add_action( 'teeny_mce_before_init', array( $this, 'add_editor_dynamic_css' ) );
			add_action( 'tiny_mce_before_init', array( $this, 'add_editor_dynamic_css' ) );
			add_action( 'wp_footer', array( $this, 'add_custom_js' ) );
			add_action( 'wp_head', array( $this, 'add_custom_css' ) );
		}

		public function register( WP_Customize_Manager $wp_customize ) {

			$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
			$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
			$wp_customize->get_setting( 'background_color' )->transport = 'postMessage';
			$wp_customize->get_setting( 'custom_logo' )->transport = 'postMessage';

			$this->selective_refresh( $wp_customize );
		}

		public function live_preview() {
			wp_enqueue_script( 'lesse-themecustomizer', LESSE_CUSTOMIZER_JS . '/customizer-live-preview.js', array(
				'jquery',
				'customize-preview',
			), '1.0', true );
		}

		public function selective_refresh( $wp_customize ) {

			// Abort if selective refresh is not available.
			if ( ! isset( $wp_customize->selective_refresh ) ) {
				return;
			}

			$wp_customize->selective_refresh->add_partial( 'custom_logo', array(
				'selector'            => '.site-branding',
				'container_inclusive' => false,
				'render_callback'     => 'lesse_site_branding',
			) );

			$wp_customize->selective_refresh->add_partial( 'lesse_hide_title', array(
				'selector'            => '.site-branding',
				'container_inclusive' => false,
				'render_callback'     => 'lesse_site_branding',
			) );
			
		}

		/**
		 * Get custom css.
		 */
		public function get_custom_css() {

			$color_selectors = apply_filters( 'lesse_color_selectors', array(
				'a',
				'a:hover',
				'.entry-footer .edit-link',
				'.comments-area .comments-title:before',
				'.lesse-scroll-icon:hover',
				'.comment-respond .comment-notes .required',
				'.lesse-hs7-menu li .current',
				'.lesse-hs7-products .lesse-product-description span:hover',
			) );

			$background_selectors = apply_filters( 'lesse_background_selectors', array(
				'button',
				'input[type=button]',
				'input[type=reset]',
				'input[type=submit]',
				'.lesse-main-navigation .sub-menu a:hover',
				'.lesse-main-navigation .flexMenu-popup a:hover',
				'.lesse-progress-bar',
				'.lesse-lite-secondary .widget_calendar #today',
				'.lesse-lite-secondary .widget_tag_cloud a:hover',
				'.site-footer .widget_calendar #today',
				'.site-footer .widget_tag_cloud a:hover',
				'.lesse-hs1-icon-container:hover',
				'.lesse-home-section-3 button',
				'.lesse-no-banner-image',
				'.hvr-sweep-to-right:before',
				'.hvr-overline-reveal:before',
				'.hvr-sweep-to-right:before',
			) );

			$border_color_selectors = apply_filters( 'lesse_border_color_selectors', array(
				'.lesse-hs2-button:hover',
				'.hvr-bubble-float-top:before',
			) );

			$border_top_color_selectors = apply_filters( 'lesse_border_top_color_selectors', array(
				'.lesse-hs4-progress-2',
				'.lesse-hs4-progress-3',
			) );

			$border_bottom_color_selectors = apply_filters( 'lesse_border_bottom_color_selectors', array(
				'.lesse-hs4-progress-3',
			) );

			$border_right_color_selectors = apply_filters( 'lesse_border_right_color_selectors', array(
				'.lesse-hs4-progress-2',
				'.lesse-hs4-progress-3',
				'.hvr-bubble-float-left:before',
				'.hvr-bubble-float-left:before',
			) );

			$color_theme_mod_name = apply_filters( 'lesse_color_theme_mod_name', 'lesse_color_scheme' );
			$color_theme_default  = apply_filters( 'lesse_color_theme_default', 'EB4D5C' );

			$this->custom_css .= lesse_generate_css( array(
				'selector'     => $border_color_selectors,
				'css_property' => 'border-color',
				'mod_name'     => $color_theme_mod_name,
				'prefix'       => '#',
				'default'      => $color_theme_default,
			) );

			$this->custom_css .= lesse_generate_css( array(
				'selector'     => $border_top_color_selectors,
				'css_property' => 'border-top-color',
				'mod_name'     => $color_theme_mod_name,
				'prefix'       => '#',
				'default'      => $color_theme_default,
			) );

			$this->custom_css .= lesse_generate_css( array(
				'selector'     => $border_bottom_color_selectors,
				'css_property' => 'border-bottom-color',
				'mod_name'     => $color_theme_mod_name,
				'prefix'       => '#',
				'default'      => $color_theme_default,
			) );

			$this->custom_css .= lesse_generate_css( array(
				'selector'     => $border_right_color_selectors,
				'css_property' => 'border-right-color',
				'mod_name'     => $color_theme_mod_name,
				'prefix'       => '#',
				'default'      => $color_theme_default,
			) );

			$this->custom_css .= lesse_generate_css( array(
				'selector'     => $color_selectors,
				'css_property' => 'color',
				'mod_name'     => $color_theme_mod_name,
				'prefix'       => '#',
				'default'      => $color_theme_default,
			) );

			$this->custom_css .= lesse_generate_css( array(
				'selector'     => $background_selectors,
				'css_property' => 'background',
				'mod_name'     => $color_theme_mod_name,
				'prefix'       => '#',
				'default'      => $color_theme_default,
			) );

			$this->custom_css .= $this->get_content_font_size_css( '.lesse-article-content' );

			return $this->custom_css;
		}

		public function generate_custom_css() {

			echo "<style id='lesse-custom-css'>/*** Lesse Customizer CSS ***/";

			echo $this->get_custom_css();

			do_action( 'lesse_custom_css' );

			echo "</style>";
		}

		/**
		 * Adds style to admin editor.
		 *
		 * @param $mceInit.
		 * @return array $mceInit.
		 */
		public function add_editor_dynamic_css( $mceInit ) {
			$css = '';

			$css .= $this->get_custom_css();

			$css .= $this->get_content_font_size_css( 'body#tinymce.mce-content-body' );

			$mceInit[ 'content_style' ] = isset( $mceInit[ 'content_style' ] ) ? $mceInit[ 'content_style' ] . ' ' . $css : $css;

			return $mceInit;
		}

		/**
		 * Generates css for content.
		 *
		 * @param string $selector.
		 * @return string css.
		 */
		public function get_content_font_size_css( $selector ) {

			$css = '';

			$content_font_size  = (int) get_theme_mod( 'lesse_content_font_size', 15 );

			if ( $content_font_size ) {
				$css .= 'body#tinymce.mce-content-body' === $selector ? $selector . '{' : 'body .site-content{';

				$css .= sprintf( 'font-size:%spx;', $content_font_size );

				$css .= '}';

				$css .= sprintf( '.widget-title{ font-size: %spx }', $content_font_size + 3 );
				$css .= sprintf( '.lesse-lite-list-view .entry-title{ font-size: %spx }', $content_font_size + 11 );
				$css .= sprintf( '.lesse-lite-list-view .entry-title{ font-size: %spx }', $content_font_size + 11 );
				$css .= sprintf( '.lesse-banner-title, .lesse-wide-thumb-content .entry-title{ font-size: %spx }', $content_font_size + 15 );
			}

			$css .= lesse_generate_css( array(
				'selector'     => $selector . ' p',
				'css_property' => 'margin-bottom',
				'mod_name'     => 'lesse_p_margin-bottom',
				'suffix'       => 'px',
				'default'      => 30,
			) );

			$css .= lesse_generate_css( array(
				'selector'     => array( $selector . ' p', $selector ),
				'css_property' => 'margin-bottom',
				'mod_name'     => 'lesse_p_margin-bottom',
				'suffix'       => 'px',
				'default'      => 30,
			) );

			for ( $i = 1; $i <= 6; $i++ ) {

				$proportion = array( 15, 10, 5, 4, 3, 2 );

				$css .= lesse_generate_css( array(
					'selector'     => $selector . ' h' . $i,
					'css_property' => 'margin-bottom',
					'mod_name'     => "lesse_h{$i}_margin-bottom",
					'suffix'       => 'px',
					'default'      => $content_font_size + $proportion[ $i - 1 ],
				) );

				$css .= lesse_generate_css( array(
					'selector'     => $selector . ' h' . $i,
					'css_property' => 'font-size',
					'mod_name'     => "lesse_h{$i}_font-size",
					'suffix'       => 'px',
					'default'      => $content_font_size + $proportion[ $i - 1 ],
				) );
			}

			return $css;
		}

		public function add_custom_js() {
			$custom_js = get_theme_mod( 'lesse_custom_code_js' );
			if ( $custom_js ) {
				printf( '<script id="lesse-lite-custom-js">(function ( $ ) { %s })( jQuery );</script>', $custom_js );
			}
		}

		public function add_custom_css() {
			$custom_css = get_theme_mod( 'lesse_custom_code_css' );
			if ( $custom_css ) {
				printf( '<style id="lesse-lite-custom-css">%s</style>', $custom_css );
			}
		}
	}
}

if ( class_exists( 'Lesse_Customizer' ) ) {
	new Lesse_Customizer();
}
